@@ -62,6 +62,9 @@ class DownloadTaskStatus(IntEnum):
     CANCELED = 4
     FAILED = 5
 
+    def __str__(self, /) -> str:
+        return repr(self)
+
     @classmethod
     def of(cls, val, /) -> Self:
         if isinstance(val, cls):
@@ -111,11 +114,9 @@ class BaseDownloadTask(ABC):
 
     def __repr__(self, /) -> str:
         name = type(self).__qualname__
-        match state := self.state:
-            case DownloadTaskStatus.FINISHED:
-                return f"<{name} :: state={state!r} result={self.result()} progress={self.progress!r}>"
-            case DownloadTaskStatus.FAILED:
-                return f"<{name} :: state={state!r} exception={self.exception()} progress={self.progress!r}>"
+        state = self.state
+        if state is DownloadTaskStatus.FAILED:
+            return f"<{name} :: state={state!r} progress={self.progress!r} exception={self.exception()}>"
         return f"<{name} :: state={state!r} progress={self.progress!r}>"
 
     @property
@@ -148,7 +149,7 @@ class BaseDownloadTask(ABC):
 
     @property
     def done(self, /) -> bool:
-        return self.state is (DownloadTaskStatus.FINISHED, DownloadTaskStatus.CANCELED, DownloadTaskStatus.FAILED)
+        return self.state in (DownloadTaskStatus.FINISHED, DownloadTaskStatus.CANCELED, DownloadTaskStatus.FAILED)
 
     def cancel(self, /):
         if not self.done:
@@ -336,9 +337,9 @@ class AsyncDownloadTask(BaseDownloadTask):
                 self.progress = await step()
         except KeyboardInterrupt:
             raise
-        except StopIteration as exc:
+        except StopAsyncIteration as exc:
             self.state = DownloadTaskStatus.FINISHED
-            self.set_result(exc.value)
+            self.set_result(None)
         except BaseException as exc:
             self.state = DownloadTaskStatus.FAILED
             self.set_exception(exc)
@@ -595,7 +596,10 @@ async def download_async_iter(
             return
 
         if filesize and is_range_request(resp):
-            await ensure_async(resp.close)()
+            if hasattr(resp, "aclose"):
+                await resp.aclose()
+            else:
+                await ensure_async(resp.close)()
             resp = await urlopen(url, headers={**headers, "Range": "bytes=%d-" % filesize})
             if not is_range_request(resp):
                 raise OSError(errno.EIO, f"range request failed: {url!r}")
@@ -621,7 +625,10 @@ async def download_async_iter(
             length_downloaded += downlen
             yield DownloadProgress(length or (length_skipped + length_downloaded), length_downloaded, length_skipped, downlen, extra)
     finally:
-        await ensure_async(resp.close)()
+        if hasattr(resp, "aclose"):
+            await resp.aclose()
+        else:
+            await ensure_async(resp.close)()
         if file_async_close:
             await file_async_close()
 
@@ -635,7 +642,7 @@ async def download_async(
     urlopen: Callable = urlopen, 
     iter_bytes: Callable = DEFAULT_ASYNC_ITER_BYTES, 
     make_reporthook: None | Callable[[None | int], Callable[[int], Any] | Generator[int, Any, Any] | AsyncGenerator[int, Any]] = None, 
-):
+) -> DownloadProgress:
     """
     """
     update: None | Callable = None
@@ -671,6 +678,7 @@ async def download_async(
         else:
             async for progress in download_gen:
                 await update(progress.last_increment)
+        return progress
     finally:
         await download_gen.aclose()
         if close is not None:
